==> jc-1.4.0.tar.gz: javax/swing/filechooser/FileFilter.c <==
// public abstract class javax.swing.filechooser.FileFilter

// class file dependencies
// @dep_class 9cef6b66128b04b2 java_io_File
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 417457cb864042ae javax_swing_filechooser_FileFilter

// header file dependencies
// @dep_header java_io_File
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_filechooser_FileFilter

#include "jc_defs.h"

#include "java/io/File.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/filechooser/FileFilter.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_swing_filechooser_FileFilter$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_filechooser_FileFilter$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_filechooser_FileFilter$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_filechooser_FileFilter$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_filechooser_FileFilter$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_filechooser_FileFilter$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_filechooser_FileFilter$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_filechooser_FileFilter, _init$52f4ad9f2989aeee);

void
_jc_javax_swing_filechooser_FileFilter$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_filechooser_FileFilter$object *this)
{
	struct _jc_javax_swing_filechooser_FileFilter$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(59);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract boolean accept(java.io.File)
//

static const unsigned char _jc_javax_swing_filechooser_FileFilter$param_ptypes$accept$0a515218e13a3730[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_javax_swing_filechooser_FileFilter$param_types$accept$0a515218e13a3730[] = {
	&_jc_java_io_File$type
};

_jc_method _jc_javax_swing_filechooser_FileFilter$method_info$accept$0a515218e13a3730 = {
	.name=			"accept",
	.signature=		"(Ljava/io/File;)Z",
	.class=			&_jc_javax_swing_filechooser_FileFilter$type,
	.param_types=		&_jc_javax_swing_filechooser_FileFilter$param_types$accept$0a515218e13a3730,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_javax_swing_filechooser_FileFilter$param_ptypes$accept$0a515218e13a3730,
	.signature_hash=	_JC_JLONG(0xa515218e13a3730),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_swing_filechooser_FileFilter$method$accept$0a515218e13a3730,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_filechooser_FileFilter$vtable, javax_swing_filechooser_FileFilter.accept$0a515218e13a3730) / sizeof(void *),
	.num_parameters=	1,
};

jboolean
_jc_javax_swing_filechooser_FileFilter$method$accept$0a515218e13a3730(_jc_env *const env, _jc_javax_swing_filechooser_FileFilter$object *this, _jc_java_io_File$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_swing_filechooser_FileFilter$method_info$accept$0a515218e13a3730);
}

//
// public abstract java.lang.String getDescription()
//

static const unsigned char _jc_javax_swing_filechooser_FileFilter$param_ptypes$getDescription$2661fc1f3e986b4b[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_filechooser_FileFilter$method_info$getDescription$2661fc1f3e986b4b = {
	.name=			"getDescription",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_swing_filechooser_FileFilter$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_swing_filechooser_FileFilter$param_ptypes$getDescription$2661fc1f3e986b4b,
	.signature_hash=	_JC_JLONG(0x2661fc1f3e986b4b),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_swing_filechooser_FileFilter$method$getDescription$2661fc1f3e986b4b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_filechooser_FileFilter$vtable, javax_swing_filechooser_FileFilter.getDescription$2661fc1f3e986b4b) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_lang_String$object *
_jc_javax_swing_filechooser_FileFilter$method$getDescription$2661fc1f3e986b4b(_jc_env *const env, _jc_javax_swing_filechooser_FileFilter$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_swing_filechooser_FileFilter$method_info$getDescription$2661fc1f3e986b4b);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_filechooser_FileFilter$methods[] = {
	&_jc_javax_swing_filechooser_FileFilter$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_filechooser_FileFilter$method_info$accept$0a515218e13a3730,
	&_jc_javax_swing_filechooser_FileFilter$method_info$getDescription$2661fc1f3e986b4b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_filechooser_FileFilter$instanceof_hash_bucket_46[] = {
	&_jc_javax_swing_filechooser_FileFilter$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_filechooser_FileFilter$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_filechooser_FileFilter$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[46]=	_jc_javax_swing_filechooser_FileFilter$instanceof_hash_bucket_46,
	[113]=	_jc_javax_swing_filechooser_FileFilter$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_filechooser_FileFilter$class_depends[] = {
	{ "java/io/File",	_JC_JLONG(0x9cef6b66128b04b2) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_filechooser_FileFilter$vtype _jc_javax_swing_filechooser_FileFilter$type = {
    .type= {
	.name=			"javax/swing/filechooser/FileFilter",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x417457cb864042ae),
		.source_file=		"FileFilter.java",
		.instance_size=		sizeof(_jc_javax_swing_filechooser_FileFilter$refs) + sizeof(_jc_javax_swing_filechooser_FileFilter$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_filechooser_FileFilter$methods) / sizeof(*_jc_javax_swing_filechooser_FileFilter$methods),
		.methods=		_jc_javax_swing_filechooser_FileFilter$methods,
		.instanceof_hash_table=	_jc_javax_swing_filechooser_FileFilter$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_swing_filechooser_FileFilter$class_depends) / sizeof(*_jc_javax_swing_filechooser_FileFilter$class_depends),
		.class_depends=		_jc_javax_swing_filechooser_FileFilter$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_filechooser_FileFilter= {
	    .accept$0a515218e13a3730=
		&_jc_javax_swing_filechooser_FileFilter$method$accept$0a515218e13a3730,
	    .getDescription$2661fc1f3e986b4b=
		&_jc_javax_swing_filechooser_FileFilter$method$getDescription$2661fc1f3e986b4b,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/filechooser/FileFilter.c <==
// public abstract class javax.swing.filechooser.FileFilter

// class file dependencies
// @dep_class 9cef6b66128b04b2 java_io_File
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 417457cb864042ae javax_swing_filechooser_FileFilter

// header file dependencies
// @dep_header java_io_File
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_filechooser_FileFilter

#include "jc_defs.h"

#include "java/io/File.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/filechooser/FileFilter.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_swing_filechooser_FileFilter$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_filechooser_FileFilter$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_filechooser_FileFilter$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_filechooser_FileFilter$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_filechooser_FileFilter$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_filechooser_FileFilter$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_filechooser_FileFilter$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_filechooser_FileFilter, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_swing_filechooser_FileFilter$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_filechooser_FileFilter$object *this)
{
	struct _jc_javax_swing_filechooser_FileFilter$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(59);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract boolean accept(java.io.File)
//

static const unsigned char _jc_javax_swing_filechooser_FileFilter$param_ptypes$accept$0a515218e13a3730[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_javax_swing_filechooser_FileFilter$param_types$accept$0a515218e13a3730[] = {
	&_jc_java_io_File$type
};

_jc_method _jc_javax_swing_filechooser_FileFilter$method_info$accept$0a515218e13a3730 = {
	.name=			"accept",
	.signature=		"(Ljava/io/File;)Z",
	.class=			&_jc_javax_swing_filechooser_FileFilter$type,
	.param_types=		&_jc_javax_swing_filechooser_FileFilter$param_types$accept$0a515218e13a3730,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_javax_swing_filechooser_FileFilter$param_ptypes$accept$0a515218e13a3730,
	.signature_hash=	_JC_JLONG(0xa515218e13a3730),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_swing_filechooser_FileFilter$method$accept$0a515218e13a3730,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_filechooser_FileFilter$vtable, javax_swing_filechooser_FileFilter.accept$0a515218e13a3730) / sizeof(void *),
	.num_parameters=	1,
};

jboolean _JC_JCNI_ATTR
_jc_javax_swing_filechooser_FileFilter$method$accept$0a515218e13a3730(_jc_env *const env, _jc_javax_swing_filechooser_FileFilter$object *this, _jc_java_io_File$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_swing_filechooser_FileFilter$method_info$accept$0a515218e13a3730);
}

//
// public abstract java.lang.String getDescription()
//

static const unsigned char _jc_javax_swing_filechooser_FileFilter$param_ptypes$getDescription$2661fc1f3e986b4b[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_swing_filechooser_FileFilter$method_info$getDescription$2661fc1f3e986b4b = {
	.name=			"getDescription",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_swing_filechooser_FileFilter$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_swing_filechooser_FileFilter$param_ptypes$getDescription$2661fc1f3e986b4b,
	.signature_hash=	_JC_JLONG(0x2661fc1f3e986b4b),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_swing_filechooser_FileFilter$method$getDescription$2661fc1f3e986b4b,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_filechooser_FileFilter$vtable, javax_swing_filechooser_FileFilter.getDescription$2661fc1f3e986b4b) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_javax_swing_filechooser_FileFilter$method$getDescription$2661fc1f3e986b4b(_jc_env *const env, _jc_javax_swing_filechooser_FileFilter$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_swing_filechooser_FileFilter$method_info$getDescription$2661fc1f3e986b4b);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_filechooser_FileFilter$methods[] = {
	&_jc_javax_swing_filechooser_FileFilter$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_filechooser_FileFilter$method_info$accept$0a515218e13a3730,
	&_jc_javax_swing_filechooser_FileFilter$method_info$getDescription$2661fc1f3e986b4b
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_filechooser_FileFilter$instanceof_hash_bucket_46[] = {
	&_jc_javax_swing_filechooser_FileFilter$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_filechooser_FileFilter$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_filechooser_FileFilter$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[46]=	_jc_javax_swing_filechooser_FileFilter$instanceof_hash_bucket_46,
	[101]=	_jc_javax_swing_filechooser_FileFilter$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_filechooser_FileFilter$class_depends[] = {
	{ "java/io/File",	_JC_JLONG(0x9cef6b66128b04b2) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_filechooser_FileFilter$vtype _jc_javax_swing_filechooser_FileFilter$type = {
    .type= {
	.name=			"javax/swing/filechooser/FileFilter",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x417457cb864042ae),
		.source_file=		"FileFilter.java",
		.instance_size=		sizeof(_jc_javax_swing_filechooser_FileFilter$refs) + sizeof(_jc_javax_swing_filechooser_FileFilter$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_filechooser_FileFilter$methods) / sizeof(*_jc_javax_swing_filechooser_FileFilter$methods),
		.methods=		_jc_javax_swing_filechooser_FileFilter$methods,
		.instanceof_hash_table=	_jc_javax_swing_filechooser_FileFilter$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_swing_filechooser_FileFilter$class_depends) / sizeof(*_jc_javax_swing_filechooser_FileFilter$class_depends),
		.class_depends=		_jc_javax_swing_filechooser_FileFilter$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_filechooser_FileFilter= {
	    .accept$0a515218e13a3730=
		&_jc_javax_swing_filechooser_FileFilter$method$accept$0a515218e13a3730,
	    .getDescription$2661fc1f3e986b4b=
		&_jc_javax_swing_filechooser_FileFilter$method$getDescription$2661fc1f3e986b4b,
	},
    }
};
